==> WindowMaker-0.60.0.tar.gz: WindowMaker-0.60.0/acconfig.h <==
/* define to the path to cpp */
#undef CPP_PATH

/* package name */
#undef PACKAGE 

/* package version */
#undef VERSION 

/* define if you want GNOME stuff support */
#undef GNOME_STUFF

/* define if you want KDE hint support */
#undef KWM_HINTS

/* define if you want OPEN LOOK(tm) hint support */
#undef OLWM_HINTS

/* define if XPM libraries are available
 * set by configure */
#undef USE_XPM

/* define if PNG libraries are available
 * set by configure */
#undef USE_PNG

/* define if JPEG libraries are available
 * set by configure */
#undef USE_JPEG

/* define if GIF libraries are available
 * set by configure */
#undef USE_GIF

/* define if TIFF libraries are available
 * set by configure */
#undef USE_TIFF

/* define if X's shared memory extension is available
 * set by configure */
#undef XSHM

/* define an extra path for pixmaps
 * set by configure */
#undef PIXMAPDIR

/*
 * define REDUCE_APPICONS if you want apps with the same WM_INSTANCE &&
 * WM_CLASS to share an appicon
 */
#undef REDUCE_APPICONS

/* Internationalization (I18N) support 
 * set by configure */
#undef I18N

/* define if you want sound support */
#undef WMSOUND

/* define if you want the 'lite' version */
#undef LITE

/* define if you want support for shaped windows
 * set by configure */
#undef SHAPE

/* define if you want support for X window's X_LOCALE
 * set by configure */
#undef X_LOCALE

/* the place where shared data is stored
 * defined by configure */
#undef PKGDATADIR

/* the place where the configuration is stored
 * defined by configure */
#undef SYSCONFDIR

/* whether XKB language MODELOCK should be enabled */
#undef XKB_MODELOCK

/* define if you want user defined menus for applications */
#undef USER_MENU

==> WindowMaker-0.64.0.tar.gz: WindowMaker-0.64.0/acconfig.h <==
/* define to the path to cpp */
#undef CPP_PATH

/* package name */
#undef PACKAGE 

/* package version */
#undef VERSION 

/* define if you want GNOME stuff support */
#undef GNOME_STUFF

/* define if you want KDE hint support */
#undef KWM_HINTS

/* define if you want OPEN LOOK(tm) hint support */
#undef OLWM_HINTS

/* define if XPM libraries are available
 * set by configure */
#undef USE_XPM

/* define if PNG libraries are available
 * set by configure */
#undef USE_PNG

/* define if JPEG libraries are available
 * set by configure */
#undef USE_JPEG

/* define if GIF libraries are available
 * set by configure */
#undef USE_GIF

/* define if TIFF libraries are available
 * set by configure */
#undef USE_TIFF

/* define if X's shared memory extension is available
 * set by configure */
#undef XSHM

/* define an extra path for pixmaps
 * set by configure */
#undef PIXMAPDIR

/*
 * define REDUCE_APPICONS if you want apps with the same WM_INSTANCE &&
 * WM_CLASS to share an appicon
 */
#undef REDUCE_APPICONS

/* Internationalization (I18N) support 
 * set by configure */
#undef I18N

/* define if you want sound support */
#undef WSOUND

/* define if you want the 'lite' version */
#undef LITE

/* define if you want support for shaped windows
 * set by configure */
#undef SHAPE


/* define if you want support for the XINERAMA extension
 * set by configure */
#undef XINERAMA

/* define if you want support for X window's X_LOCALE
 * set by configure */
#undef X_LOCALE

/* the place where shared data is stored
 * defined by configure */
#undef PKGDATADIR

/* the place where the configuration is stored
 * defined by configure */
#undef SYSCONFDIR

/* whether XKB language MODELOCK should be enabled */
#undef XKB_MODELOCK

/* define if you want user defined menus for applications */
#undef USER_MENU

/* define if you have then inet_aton function */
#undef HAVE_INET_ATON

/* define if your X server has XInternAtoms() */
#undef HAVE_XINTERNATOMS

/* define if processor is x86 */
#undef ASM_X86

/* define if processor is x86 with MMX(tm) support */
#undef ASM_X86_MMX
